@@ -3,6 +3,7 @@ package pingone
 import (
 	"bytes"
 	"os"
+	"reflect"
 	"testing"
 
 	"github.com/PuerkitoBio/goquery"
@@ -40,3 +41,29 @@ func TestDocTypes(t *testing.T) {
 		}
 	}
 }
+
+var deviceNameTests = []struct {
+	file     string
+	expected map[string]string
+}{
+	{"example/selectdevice.html", map[string]string{"iPhone": "3270134077889335000", "Android": "3964291169487703000"}},
+	{"example/selectdevicebutton.html", map[string]string{"iPhone": "3270134077889335000", "Android": "3964291169487703000"}},
+}
+
+func TestFindDeviceMap(t *testing.T) {
+	for _, tt := range deviceNameTests {
+		data, err := os.ReadFile(tt.file)
+		require.Nil(t, err)
+
+		doc, err := goquery.NewDocumentFromReader(bytes.NewReader(data))
+		require.Nil(t, err)
+
+		deviceMap := findDeviceMap(doc)
+
+		eq := reflect.DeepEqual(deviceMap, tt.expected)
+
+		if eq != true {
+			t.Errorf("expected deviceMap %v to be %v", deviceMap, tt.expected)
+		}
+	}
+}
